/*
 * 	config.h - Config loading for Glacier
 *
 * 	This file is part of Glacier.
 *
 * 	Glacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU Lesser General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Glacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * 	You should have received a copy of the GNU Lesser General Public License along with Glacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

#ifndef GLACIERCONFIG_H_
#define GLACIERCONFIG_H_

#include <libconfig.h>

/* Constants */
#ifndef LG_VERBOSE
#define LG_VERBOSE 0
#endif

/*
 * init_config
 *
 * DESCRIPTION: Initialize libconfig with required configs
 * PARAMETERS:
 * 		None.
 * RETURN VALUES:
 * 		0 on success, 1 on failure
 * CAVEATS:
 * 		This MUST be called before ANY other config function is.
 * EXAMPLE:
 * 		init_config();
 */

int init_config(void);

/*
 * die_config
 *
 * DESCRIPTION: Die_config brings down libconfig gracefully.
 * PARAMETERS:
 * 		None.
 * RETURN VALUES:
 * 		0 on success, 1 on failure
 * CAVEATS:
 * 		This MUST be called after ALL other config functions have completed.
 * EXAMPLE:
 * 		die_config();
 */

int die_config(void);

/*
 * load_all_from_config
 *
 * DESCRIPTION: load_all_from_config loads all settings from the config file.
 * PARAMETERS:
 * 		None.
 * RETURN VALUES:
 * 		0 on success, 1 on failure
 * CAVEATS:
 * 		None.
 * EXAMPLE:
 * 		load_all_from_config();
 */

int load_all_from_config(void);

/*
 * load_all_from_profile
 *
 * DESCRIPTION: load_all_from_profile loads all settings from the profile file.
 * PARAMETERS:
 * 		None.
 * RETURN VALUES:
 * 		0 on success, 1 on failure
 * CAVEATS:
 * 		None.
 * EXAMPLE:
 * 		load_all_from_profile();
 */

int load_all_from_profile(void);

#endif
